@@ -174,18 +174,18 @@ class Dataset(object):
         of the form: {group: dataset, ...}.
         """
         response = self._connection.make_api_request(
-            'GET', '/datasets/%s/related' % self._id)
+            'GET', '/datasets/%s/aggregations' % self._id)
         return dict([(group, Dataset(dataset_id, connection=self._connection))
                      for group, dataset_id in response.iteritems()])
 
     def get_summary(self, select='all', groups=None, query=None,
-                    num_retries=NUM_RETRIES):
+                    num_retries=NUM_RETRIES, order_by=None, limit=0):
         """
         Returns the summary information for this dataset.
         """
         @require_valid
         @retry(num_retries)
-        def _get_summary(self, select, groups, query):
+        def _get_summary(self, select, groups, query, order_by, limit):
             params = {}
             # TODO: check input params
             if select != 'all':
@@ -209,9 +209,21 @@ class Dataset(object):
                 params['query'] = safe_json_dumps(
                     query,
                     PyBambooException('query is not JSON-serializable.'))
+            if order_by:
+                if not isinstance(order_by, basestring):
+                    raise PyBambooException('order_by must be a string.')
+                params['order_by'] = safe_json_dumps(
+                    order_by,
+                    PyBambooException('order_by is not JSON-serializable.'))
+            if limit:
+                if not isinstance(limit, int):
+                    raise PyBambooException('limit must be an int.')
+                params['limit'] = safe_json_dumps(
+                    limit,
+                    PyBambooException('limit is not JSON-serializable.'))
             return self._connection.make_api_request(
                 'GET', '/datasets/%s/summary' % self._id, params=params)
-        return _get_summary(self, select, groups, query)
+        return _get_summary(self, select, groups, query, order_by, limit)
 
     def get_info(self, num_retries=NUM_RETRIES):
         """
@@ -224,14 +236,15 @@ class Dataset(object):
                 'GET', '/datasets/%s/info' % self._id)
         return _get_info(self)
 
-    def get_data(self, select=None, query=None, num_retries=NUM_RETRIES):
+    def get_data(self, select=None, query=None, num_retries=NUM_RETRIES,
+                 order_by=None, limit=0):
         """
         Returns the rows in this dataset filtered by the given
         select and query.
         """
         @require_valid
         @retry(num_retries)
-        def _get_data(self, select, query):
+        def _get_data(self, select, query, order_by, limit):
             params = {}
             if select:
                 if not isinstance(select, list):
@@ -247,9 +260,21 @@ class Dataset(object):
                 params['query'] = safe_json_dumps(
                     query,
                     PyBambooException('query is not JSON-serializable.'))
+            if order_by:
+                if not isinstance(order_by, basestring):
+                    raise PyBambooException('order_by must be a string.')
+                params['order_by'] = safe_json_dumps(
+                    order_by,
+                    PyBambooException('order_by is not JSON-serializable.'))
+            if limit:
+                if not isinstance(limit, int):
+                    raise PyBambooException('limit must be an int.')
+                params['limit'] = safe_json_dumps(
+                    limit,
+                    PyBambooException('limit is not JSON-serializable.'))
             return self._connection.make_api_request(
                 'GET', '/datasets/%s' % self._id, params=params)
-        return _get_data(self, select, query)
+        return _get_data(self, select, query, order_by, limit)
 
     @require_valid
     def update_data(self, rows):
@@ -331,6 +356,20 @@ class Dataset(object):
             return Dataset(result['id'], connection=connection)
         return False
 
+    def count(self, field, method='count'):
+        """ Number of rows/submissions for a given field.
+
+        For measure fields method is one of:
+        '25%', '50%', '75%', 'count' (default), 'max', 'mean', 'min', 'std' """
+
+        value = self.get_summary().get(field).get('summary')
+        if not isinstance(value, dict):
+            raise PyBambooException('summary not available.')
+        if method in value:
+            return float(value.get(method))
+        else:
+            return sum((int(relval) for relval in value.values()))
+
     @property
     def id(self):
         """
